"""Top-level package for sparsemax."""
# fmt: off
__author__ = """Laksh Aithani"""
__email__ = "lakshaithanii@gmail.com"
__version__ = '0.1.9'

from sparsemax.sparsemax import Sparsemax
# fmt: on
